# jsonclasses

Python @dataclass <=> JSON declarable, interchangeable, validatable, sanitizable.

## Motivation

Python lacks a great solution of JSON web inputs, JSON objects manipulation and
serialization. By declaring field specifications with Python class and
@dataclass, we can solve this issue elegantly.

## Example

### Converting from dict

### Coverting to dict

### Sanitization

### Validation

### Integration with web frameworks

Using `jsonclasses` with `sanic` web framework.

```python

```

Using `jsonclasses` with `flask` web framework.

```python

```

## Installation

Install `jsonclasses` package with `pip`.

```sh
pip install jsonclasses
```

## Supported Python versions

`jsonclasses` supports `Python >= 3.5`.

## License
